import { AbstractDynamicSnippetsGeneratorContext, FernGeneratorExec } from '@fern-api/browser-compatible-base-generator';
import { FernIr } from '@fern-api/dynamic-ir-sdk';
import { python } from '@fern-api/python-ast';
import { BasePythonCustomConfigSchema } from '@fern-api/python-browser-compatible-base';

declare namespace DynamicTypeLiteralMapper {
    interface Args {
        typeReference: FernIr.dynamic.TypeReference;
        value: unknown;
        as?: ConvertedAs;
    }
    type ConvertedAs = "key";
}
declare class DynamicTypeLiteralMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    convert(args: DynamicTypeLiteralMapper.Args): python.TypeInstantiation;
    private convertLiteral;
    private convertList;
    private convertSet;
    private convertMap;
    private convertNamed;
    private convertDiscriminatedUnion;
    private convertDiscriminatedUnionProperties;
    private getBaseFields;
    private convertObject;
    private convertEnum;
    private getEnumValue;
    private convertUndiscriminatedUnion;
    private findMatchingUndiscriminatedUnionType;
    private convertPrimitive;
    private getValueAsNumber;
    private getValueAsBoolean;
}

interface FilePropertyInfo {
    fileFields: python.NamedValue[];
    bodyPropertyFields: python.NamedValue[];
}
declare class FilePropertyMapper {
    private context;
    constructor({ context }: {
        context: DynamicSnippetsGeneratorContext;
    });
    getFilePropertyInfo({ body, value }: {
        body: FernIr.dynamic.FileUploadRequestBody;
        value: unknown;
    }): FilePropertyInfo;
    private getSingleFileProperty;
    private getArrayFileProperty;
    private getBodyProperty;
}

declare class DynamicSnippetsGeneratorContext extends AbstractDynamicSnippetsGeneratorContext {
    ir: FernIr.dynamic.DynamicIntermediateRepresentation;
    customConfig: BasePythonCustomConfigSchema;
    dynamicTypeLiteralMapper: DynamicTypeLiteralMapper;
    filePropertyMapper: FilePropertyMapper;
    constructor({ ir, config }: {
        ir: FernIr.dynamic.DynamicIntermediateRepresentation;
        config: FernGeneratorExec.GeneratorConfig;
    });
    clone(): DynamicSnippetsGeneratorContext;
    getClassName(name: FernIr.Name): string;
    getTypedDictClassName(name: FernIr.Name): string;
    getPropertyName(name: FernIr.Name): string;
    getMethodName(name: FernIr.Name): string;
    getRootClientClassReference(): python.Reference;
    getRootClientClassName(): string;
    getEnvironmentClassName(): string;
    getEnvironmentTypeReferenceFromID(environmentID: string): python.AstNode | undefined;
    getEnvironmentClassReference(): python.Reference;
    getEnvironmentEnumName(name: FernIr.Name): string;
    isPrimitive(typeReference: FernIr.dynamic.TypeReference): boolean;
    getFileFromString(content: string): python.TypeInstantiation;
    getRootModulePath(): string[];
    getCoreModulePath(): string[];
    getEnvironmentModulePath(): string[];
    shouldInlinePathParameters(): boolean;
    private cleanOrganizationName;
    private getApiName;
    private pascalCase;
}

export { DynamicSnippetsGeneratorContext as D, type FilePropertyInfo as F, DynamicTypeLiteralMapper as a, FilePropertyMapper as b };
